@@ -77,7 +77,7 @@ NULL
 #' @export
 add_binary_decisions <- function(x) {
   # assert argument is valid
-  rlang::check_required(x)
+  assert_required(x)
   assert(is_conservation_problem(x))
   # add decision
   x$add_decisions(
