@@ -12,13 +12,13 @@ NULL
 #'
 #' @details For a conservation planning [problem()] with multiple
 #'   management zones, it may sometimes be desirable to obtain a solution that
-#'   assigns each and every single planning unit to a zone. For example, when
-#'   developing land-use plans, some decision makers may require that each and
-#'   every single parcel of land has been allocated a specific land-use type.
+#'   assigns each and every planning unit to a zone. For example, when
+#'   developing land-use plans, some decision makers may require that
+#'   every parcel of land is allocated a specific land-use type.
 #'   In other words are no "left over" areas. Although it might seem tempting
 #'   to simply solve the problem and manually assign "left over" planning units
 #'   to a default zone afterwards (e.g., an "other", "urban", or "grazing"
-#'   land-use), this could result in highly sub-optimal solutions if there
+#'   land-use), this could result in highly sub-optimal solutions if there are
 #'   penalties for siting the default land-use adjacent to other zones.
 #'   Instead, this function can be used to specify that all planning units in a
 #'   problem with multiple zones must be allocated to a management zone (i.e.,
@@ -73,7 +73,7 @@ NULL
 #' @export
 add_mandatory_allocation_constraints <- function(x) {
   # assert valid arguments
-  rlang::check_required(x)
+  assert_required(x)
   assert(
     is_conservation_problem(x),
     number_of_zones(x) >= 2
