@@ -222,7 +222,7 @@ methods::setMethod("add_manual_bounded_constraints",
         public = list(
           name = "manual bounded constraints",
           data = list(data = data),
-          repr = function() {
+          repr = function(compact = TRUE) {
             paste0(
               self$name, " (", nrow(self$get_data("data")),
               " planning units)"
@@ -240,14 +240,10 @@ methods::setMethod("add_manual_bounded_constraints",
             if (!assertthat::has_name(d, "zone"))
               d$zone <- y$zone_names()[1]
             d$zone <- match(as.character(d$zone), y$zone_names())
-            # remove rows for raster cells that aren't really planning units
-            # i.e., contain NA values in all zones
-            pu <- y$get_data("cost")
-            if (inherits(pu, c("SpatRaster", "Raster"))) {
-              units <- y$planning_unit_indices()
-              d$pu <- match(d$pu, units)
-              d <- d[!is.na(d$pu), , drop = FALSE]
-            }
+            # convert from total units to planning units
+            units <- y$planning_unit_indices()
+            d$pu <- match(d$pu, units)
+            d <- d[!is.na(d$pu), , drop = FALSE]
             # apply constraints
             invisible(
               rcpp_apply_bounded_constraints(
