@@ -125,8 +125,8 @@ NULL
 #' @export
 add_min_largest_shortfall_objective <- function(x, budget) {
   # assert arguments are valid
-  rlang::check_required(x)
-  rlang::check_required(budget)
+  assert_required(x)
+  assert_required(budget)
   assert(
     is_conservation_problem(x),
     is.numeric(budget),
