@@ -124,13 +124,15 @@ add_top_portfolio <- function(x, number_solutions = 10) {
           ## compile results
           if (!is.null(sol$pool)) {
             sol <- append(
-              list(sol[-5]),
+              list(sol[-which(names(sol) == "pool")]),
               lapply(
                 sol$pool,
                 function(z) list(
-                  x = z$xn, objective = z$objval,
+                  x = z$xn,
+                  objective = z$objective,
                   status = z$status,
-                  runtime = sol$runtime
+                  runtime = sol$runtime,
+                  gap = z$gap
                 )
               )
             )
