@@ -235,8 +235,8 @@ NULL
 #' @export
 eval_feature_representation_summary <- function(x, solution) {
   # assert arguments are valid
-  rlang::check_required(x)
-  rlang::check_required(solution)
+  assert_required(x)
+  assert_required(solution)
   assert(is_conservation_problem(x))
   # extract solution
   solution <- planning_unit_solution_status(x, solution)
