@@ -28,14 +28,16 @@ NULL
 #' print(number_of_features(p))
 #' }
 #' @export
-number_of_features <- function(x, ...) UseMethod("number_of_features")
+number_of_features <- function(x, ...) {
+  assert_required(x)
+  rlang::check_dots_empty()
+  UseMethod("number_of_features")
+}
 
 #' @rdname number_of_features
 #'
 #' @export
 number_of_features.ConservationProblem <- function(x, ...) {
-  rlang::check_required(x)
-  rlang::check_dots_empty()
   x$number_of_features()
 }
 
@@ -43,8 +45,6 @@ number_of_features.ConservationProblem <- function(x, ...) {
 #'
 #' @export
 number_of_features.OptimizationProblem <- function(x, ...) {
-  rlang::check_required(x)
-  rlang::check_dots_empty()
   x$number_of_features()
 }
 
@@ -52,8 +52,6 @@ number_of_features.OptimizationProblem <- function(x, ...) {
 #'
 #' @export
 number_of_features.ZonesSpatRaster <- function(x, ...) {
-  rlang::check_required(x)
-  rlang::check_dots_empty()
   terra::nlyr(x[[1]])
 }
 
@@ -61,8 +59,6 @@ number_of_features.ZonesSpatRaster <- function(x, ...) {
 #'
 #' @export
 number_of_features.ZonesRaster <- function(x, ...) {
-  rlang::check_required(x)
-  rlang::check_dots_empty()
   raster::nlayers(x[[1]])
 }
 
@@ -70,7 +66,5 @@ number_of_features.ZonesRaster <- function(x, ...) {
 #'
 #' @export
 number_of_features.ZonesCharacter <- function(x, ...) {
-  rlang::check_required(x)
-  rlang::check_dots_empty()
   length(x[[1]])
 }
