@@ -17,14 +17,19 @@ NULL
 #'
 #' @param memory `logical` should calculations be performed using a method
 #'   that prioritizes reduced memory consumption over speed?
-#'   If `TRUE`, then calculations are performed using a method that
-#'   reduces memory consumption, but can take a long time to complete.
-#'   If `FALSE`, then calculations are performed using a method that
-#'   reduces run time, but will fail when insufficient memory is available.
-#'   Defaults to `NA`, such that calculations are automatically performed
-#'   using the best method given available memory and dataset sizes.
-#'   Note that this parameter can only be used when the arguments to `x`
-#'   and `y` are both [terra::rast()] objects.
+#'   This is useful when processing particularly large raster datasets.
+#'   If `TRUE`, then calculations are performed by processing each raster layer
+#'   in `y` in a sequential manner.
+#'   If `FALSE`, then calculations are performed by processing all raster layers
+#'   in `y` together.
+#'   If `NA`, then the memory requirements will be estimated and, if required,
+#'   processing will be performed using the method that reduces memory
+#'   consumption.
+#'   Defaults to `NA`.
+#'
+#' @param idx `integer` vector containing planning unit
+#'   indices. Defaults to `NULL` such that the indices are computed
+#'   automatically based on `x`.
 #'
 #' @param ... not used.
 #'
@@ -41,7 +46,7 @@ NULL
 #' terra::gdalCache(size = 4000)
 #' ```
 #'
-#' @return A [`dgCMatrix-class`] sparse matrix object.
+#' @return A [`Matrix::dgCMatrix-class`] sparse matrix object.
 #'   The sparse matrix represents the spatial intersection between the
 #'   planning units and the features. Rows correspond to features,
 #'   and columns correspond to planning units. Values correspond to the amount
@@ -91,23 +96,12 @@ methods::setGeneric(
 )
 
 #' @name rij_matrix
-#' @usage \S4method{rij_matrix}{Raster,Raster}(x, y, ...)
-#' @rdname rij_matrix
-methods::setMethod(
-  "rij_matrix",
-  signature(x = "Raster", y = "Raster"),
-  function(x, y, ...) {
-    cli_warning(raster_pkg_deprecation_notice)
-    rij_matrix(terra::rast(x), terra::rast(y), ...)
-})
-
-#' @name rij_matrix
-#' @usage \S4method{rij_matrix}{SpatRaster,SpatRaster}(x, y, memory, ...)
+#' @usage \S4method{rij_matrix}{SpatRaster,SpatRaster}(x, y, memory, idx, ...)
 #' @rdname rij_matrix
 methods::setMethod(
   "rij_matrix",
   signature(x = "SpatRaster", y = "SpatRaster"),
-  function(x, y, memory = NA, ...) {
+  function(x, y, memory = NA, idx = NULL, ...) {
     # assert that arguments are valid
     assert(
       inherits(x, "SpatRaster"),
@@ -119,45 +113,44 @@ methods::setMethod(
       is_comparable_raster(x, y),
       assertthat::is.flag(memory)
     )
+    if (!is.null(idx)) {
+      assert(
+        is.numeric(idx),
+        length(idx) > 0
+      )
+    }
     assert_dots_empty()
-    # identify included cells
-    idx <- terra::cells(terra::allNA(x), 0)[[1]]
-    # if memory is NA, then set it automatically..
+    # if needed, identify cells that should be considered planning units
+    if (is.null(idx)) {
+      idx <- planning_unit_indices(x)
+    }
+    # if needed, determine if calculations can be done in memory
     if (is.na(memory)) {
-      mem_needed_kb <-
-        ((40 * length(idx)) + (terra::nlyr(y) * length(idx) * 8)) * 0.001
-      memory <- isTRUE(mem_needed_kb > terra::free_RAM())
+      memory <- !terra_can_process_in_memory(y, n = 1)
     }
     # run processing
     if (!isTRUE(memory)) {
-      # generate matrix
+      ## generate matrix
       m <- as.matrix(y[idx])
       m[is.na(m)] <- 0
       m <- Matrix::t(Matrix::drop0(methods::as(m, "dgCMatrix")))
     } else {
-      # initialize matrix
-      m <- Matrix::sparseMatrix(
-        i = 1, j = 1, x = 0, repr = "C",
-        dims = c(terra::nlyr(y), length(idx))
+      ## determine number of layers to process at once
+      nl <- terra_n_process_in_memory(y[[c(1, 2)]])
+      ## split layers into chunks
+      lidx <- parallel::splitIndices(
+        terra::nlyr(y),
+        ceiling(terra::nlyr(y) / nl)
       )
-      # determine number of layers to process at once
-      n_layers <-
-        ((40 * length(idx)) + (rep(1, terra::nlyr(y)) * length(idx) * 8))
-      n_layers <- max(
-        c(1, which(cumsum(n_layers) < (terra::free_RAM() * 0.45)))
-      )
-      layer_ind <- parallel::splitIndices(
-        terra::nlyr(y), ceiling(terra::nlyr(y) / n_layers)
-      )
-      # import data and add to matrix
-      for (i in seq_along(layer_ind)) {
-        v <- t(as.matrix(y[[layer_ind[[i]]]][idx]))
-        v[is.na(v)] <- 0
-        m[layer_ind[[i]], ] <- v
-        rm(v)
-        m <- Matrix::drop0(m)
+      ## import layers in batches and add to matrix
+      m <- do.call(rbind, lapply(seq_along(lidx), function(j) {
+        k <- as.matrix(y[[lidx[[j]]]][idx])
+        k[is.na(k)] <- 0
+        k <- Matrix::t(Matrix::drop0(methods::as(k, "dgCMatrix")))
         invisible(gc())
-      }
+        k
+      }))
+      m <- as_Matrix(m, "dgCMatrix")
     }
     # add row names
     rownames(m) <- names(y)
@@ -166,39 +159,91 @@ methods::setMethod(
 })
 
 #' @name rij_matrix
-#' @usage \S4method{rij_matrix}{Spatial,Raster}(x, y, fun, ...)
-#' @rdname rij_matrix
-methods::setMethod(
-  "rij_matrix",
-  signature(x = "Spatial", y = "Raster"),
-  function(x, y, fun = "sum", ...) {
-    cli_warning(sp_pkg_deprecation_notice)
-    rij_matrix(sf::st_as_sf(x), y, fun = fun, ...)
-})
-
-#' @name rij_matrix
-#' @usage \S4method{rij_matrix}{sf,Raster}(x, y, fun, ...)
-#' @rdname rij_matrix
-methods::setMethod(
-  "rij_matrix",
-  signature(x = "sf", y = "Raster"),
-  function(x, y, fun = "sum", ...) {
-    cli_warning(raster_pkg_deprecation_notice)
-    rij_matrix(x, terra::rast(y), fun = fun, ...)
-})
-
-#' @name rij_matrix
-#' @usage \S4method{rij_matrix}{sf,SpatRaster}(x, y, fun, ...)
+#' @usage \S4method{rij_matrix}{sf,SpatRaster}(x, y, fun, memory, idx, ...)
 #' @rdname rij_matrix
 methods::setMethod(
   "rij_matrix",
   signature(x = "sf", y = "SpatRaster"),
-  function(x, y, fun = "sum", ...) {
-    assert(is_numeric_values(y))
+  function(x, y, fun = "sum", memory = FALSE, idx = NULL, ...) {
+    # assert arguments valid
+    assert(
+      is_numeric_values(y),
+      terra::nlyr(y) > 0,
+      assertthat::is.flag(memory)
+    )
     assert_dots_empty()
-    m <- fast_extract(x = y, y = x, fun = fun)
-    m[is.na(m[])] <- 0
-    m <- Matrix::drop0(methods::as(m, "dgCMatrix"))
-    colnames(m) <- names(y)
-    Matrix::t(m)
+    # if needed, determine if calculations can be done in memory
+    if (is.na(memory)) {
+      memory <- !terra_can_process_in_memory(y, n = 1)
+    }
+    # if needed, subset x according to indices
+    if (!is.null(idx)) {
+      assert(
+        is.numeric(idx),
+        length(idx) > 0
+      )
+      x <- x[idx, , drop = FALSE]
+    }
+    # main processing
+    if (!isTRUE(memory)) {
+      ## extract data for all layers
+      m <- fast_extract(x = y, y = x, fun = fun)
+      m[is.na(m)] <- 0
+      m <- Matrix::drop0(methods::as(m, "dgCMatrix"))
+      m <- Matrix::t(m)
+    } else {
+      ## determine number of layers to process at once
+      nl <- terra_n_process_in_memory(y[[c(1, 2)]])
+      ## split layers into chunks
+      lidx <- parallel::splitIndices(
+        terra::nlyr(y),
+        ceiling(terra::nlyr(y) / nl)
+      )
+      ## import layers in batches and add to matrix
+      m <- do.call(rbind, lapply(seq_along(lidx), function(j) {
+        k <- fast_extract(x = y[[lidx[[j]]]], y = x, fun = fun)
+        k[is.na(k)] <- 0
+        k <- Matrix::t(Matrix::drop0(methods::as(k, "dgCMatrix")))
+        invisible(gc())
+        k
+      }))
+      m <- as_Matrix(m, "dgCMatrix")
+    }
+    # add row names
+    rownames(m) <- names(y)
+    # return result
+    m
+})
+
+#' @name rij_matrix
+#' @usage \S4method{rij_matrix}{Raster,Raster}(x, y, memory, idx, ...)
+#' @rdname rij_matrix
+methods::setMethod(
+  "rij_matrix",
+  signature(x = "Raster", y = "Raster"),
+  function(x, y, memory = NA, idx = NULL, ...) {
+    cli_warning(raster_pkg_deprecation_notice)
+    rij_matrix(terra::rast(x), terra::rast(y), memory = memory, idx = idx, ...)
+})
+
+#' @name rij_matrix
+#' @usage \S4method{rij_matrix}{sf,Raster}(x, y, fun, memory, idx, ...)
+#' @rdname rij_matrix
+methods::setMethod(
+  "rij_matrix",
+  signature(x = "sf", y = "Raster"),
+  function(x, y, fun = "sum", memory = NA, idx = NULL, ...) {
+    cli_warning(raster_pkg_deprecation_notice)
+    rij_matrix(x, terra::rast(y), fun = fun, memory = memory, idx = idx, ...)
+})
+
+#' @name rij_matrix
+#' @usage \S4method{rij_matrix}{Spatial,Raster}(x, y, fun, memory, idx, ...)
+#' @rdname rij_matrix
+methods::setMethod(
+  "rij_matrix",
+  signature(x = "Spatial", y = "Raster"),
+  function(x, y, fun = "sum", memory = NA, idx = NULL, ...) {
+    cli_warning(sp_pkg_deprecation_notice)
+    rij_matrix(sf::st_as_sf(x), y, fun = fun, memory = memory, idx = idx, ...)
 })
