@@ -13,7 +13,7 @@ NULL
 #'
 #' @name show
 #'
-#' @aliases show,ConservationProblem-method show,ConservationModifier-method show,OptimizationProblem-method show,Id-method show,Parameter-method show,Solver-method
+#' @aliases show,ConservationProblem-method show,ConservationModifier-method show,OptimizationProblem-method show,Id-method show,Solver-method
 NULL
 
 #' @name show
@@ -34,15 +34,6 @@ methods::setMethod("show", "ConservationModifier",
 methods::setMethod("show", "ConservationProblem",
                    function(object) object$show())
 
-#' @name show
-#'
-#' @rdname show
-#'
-#' @usage \S4method{show}{Id}(x)
-#'
-methods::setMethod("show", "Id",
-                   function(object) print.Id(object))
-
 #' @name show
 #'
 #' @rdname show
@@ -52,15 +43,6 @@ methods::setMethod("show", "Id",
 methods::setMethod("show", "OptimizationProblem",
                    function(object) object$show())
 
-#' @name show
-#'
-#' @rdname show
-#'
-#' @usage \S4method{show}{Parameter}(x)
-#'
-methods::setMethod("show", "Parameter",
-                   function(object) object$show())
-
 #' @name show
 #'
 #' @rdname show
