@@ -1,4 +1,4 @@
-#' @include internal.R pproto.R ConservationProblem-proto.R
+#' @include internal.R ConservationProblem-class.R
 NULL
 
 #' Add representation targets
@@ -33,13 +33,15 @@ NULL
 #' @examples
 #' \dontrun{
 #' # load data
-#' data(sim_pu_raster, sim_features)
+#' sim_pu_raster <- get_sim_pu_raster()
+#' sim_features <- get_sim_features()
 #'
 #' # create base problem
-#' p <- problem(sim_pu_raster, sim_features) %>%
-#'      add_min_set_objective() %>%
-#'      add_binary_decisions() %>%
-#'      add_default_solver(verbose = FALSE)
+#' p <-
+#'   problem(sim_pu_raster, sim_features) %>%
+#'   add_min_set_objective() %>%
+#'   add_binary_decisions() %>%
+#'   add_default_solver(verbose = FALSE)
 #'
 #' # create problem with added relative targets
 #' p1 <- p %>% add_relative_targets(0.1)
@@ -51,24 +53,22 @@ NULL
 #' p3 <- p %>% add_loglinear_targets(10, 0.9, 100, 0.2)
 #'
 #' # create problem with manual targets that equate to 10% relative targets
-#' p4 <- p %>% add_manual_targets(data.frame(feature = names(sim_features),
-#'                                           target = 0.1,
-#'                                           type = "relative"))
+#' targs <- data.frame(
+#'   feature = names(sim_features),
+#'   target = 0.1,
+#'   type = "relative"
+#' )
+#'
+#' p4 <- p %>% add_manual_targets(targs)
 #'
 #' # solve problem
-#' s <- stack(solve(p1), solve(p2), solve(p3), solve(p4))
-#'
+#' s <- c(solve(p1), solve(p2), solve(p3), solve(p4))
+#' names(s) <- c(
+#'   "relative targets", "absolute targets", "loglinear targets",
+#'   "manual targets"
+#' )
 #' # plot solution
-#' plot(s, axes = FALSE, box = FALSE,
-#'      main = c("relative targets", "absolute targets", "loglinear targets",
-#'               "manual targets"))
+#' plot(s, axes = FALSE)
 #' }
 #' @name targets
 NULL
-
-add_default_targets <- function(x) {
-  # assert arguments are valid
-  assertthat::assert_that(inherits(x, "ConservationProblem"))
-  # throw error because targets must be supplied
-  stop("specified objective function requires targets")
-}
