@@ -1,3 +1,34 @@
+test_that("maximum utility objective (numeric, compile, single zone)", {
+  # import data
+  sim_pu_raster <- get_sim_pu_raster()
+  sim_features <- get_sim_features()
+  # create problems
+  p1 <-
+    problem(sim_pu_raster, sim_features) %>%
+    add_max_utility_objective(budget = 5) %>%
+    add_binary_decisions()
+  p2 <-
+    p1 %>%
+    add_linear_penalties(3, c(terra::values(sim_features[[1]])) * 8)
+  # solve problems
+  o1 <- compile(p1)
+  o2 <- compile(p2)
+  # calculations for tests
+  pu_idx <- p1$planning_unit_indices()
+  pen <- c(
+    3 * sim_features[[1]][pu_idx][[1]] * 8,
+    rep(0, terra::nlyr(sim_features))
+  )
+  # tests
+  expect_equal(o2$obj(), o1$obj() - pen)
+  expect_equal(o2$A(), o1$A())
+  expect_equal(o2$ub(), o1$ub())
+  expect_equal(o2$lb(), o1$lb())
+  expect_equal(o2$rhs(), o1$rhs())
+  expect_equal(o2$sense(), o1$sense())
+  expect_equal(o2$modelsense(), o1$modelsense())
+})
+
 test_that("minimum set objective (numeric, compile, single zone)", {
   # import data
   sim_pu_raster <- get_sim_pu_raster()
@@ -45,10 +76,14 @@ test_that("minimum set objective (matrix, compile, single zone)", {
   p3 <-
     p1 %>%
     add_linear_penalties(3, as_Matrix(pd, "dgCMatrix"))
+  p4 <-
+    p1 %>%
+    add_linear_penalties(3, as_Matrix(pd, "dgTMatrix"))
   # solve problems
   o1 <- compile(p1)
   o2 <- compile(p2)
   o3 <- compile(p3)
+  o4 <- compile(p4)
   # calculations for tests
   pu_idx <- p1$planning_unit_indices()
   # tests
@@ -60,6 +95,7 @@ test_that("minimum set objective (matrix, compile, single zone)", {
   expect_equal(o2$sense(), o1$sense())
   expect_equal(o2$modelsense(), o1$modelsense())
   expect_equal(as.list(o2), as.list(o3))
+  expect_equal(as.list(o2), as.list(o4))
 })
 
 test_that("minimum set objective (raster, compile, single zone)", {
