@@ -1,5 +1,3 @@
-context("add_locked_in_constraints")
-
 test_that("integer (compile, single zone)", {
   # create problem
   sim_pu_raster <- get_sim_pu_raster()
@@ -73,7 +71,7 @@ test_that("logical (compile, single zone)", {
   expect_tidy_error(
     add_locked_in_constraints(
       p,
-      c(TRUE, NA_logical, rep(FALSE, terra::ncell(sim_pu_raster) - 2))
+      c(TRUE, NA, rep(FALSE, terra::ncell(sim_pu_raster) - 2))
     )
   )
 })
@@ -417,7 +415,7 @@ test_that("raster (compile, single zone)", {
   # check that invalid inputs throw errors
   expect_tidy_error({
     sim_locked_in_raster <- get_sim_locked_in_raster()
-    extent(sim_locked_in_raster) <- c(0, 20, 0, 20)
+    terra::ext(sim_locked_in_raster) <- c(0, 20, 0, 20)
     problem(sim_pu_raster, sim_features) %>%
       add_min_set_objective() %>%
       add_relative_targets(0.1) %>%
@@ -694,15 +692,19 @@ test_that(
     add_binary_decisions() %>%
     add_locked_in_constraints(c("locked_1", "locked_2", "locked_3"))
   expect_warning(
-    p2 <-
-      problem(
-        sim_spatial, as.ZonesRaster(sim_zones_features),
-        c("cost_1", "cost_2", "cost_3")
-      ) %>%
-      add_min_set_objective() %>%
-      add_relative_targets(targets) %>%
-      add_binary_decisions() %>%
-      add_locked_in_constraints(c("locked_1", "locked_2", "locked_3"))
+    expect_warning(
+      p2 <-
+        problem(
+          sim_spatial, as.ZonesRaster(sim_zones_features),
+          c("cost_1", "cost_2", "cost_3")
+        ) %>%
+        add_min_set_objective() %>%
+        add_relative_targets(targets) %>%
+        add_binary_decisions() %>%
+        add_locked_in_constraints(c("locked_1", "locked_2", "locked_3")),
+      "deprecated"
+    ),
+    "deprecated"
   )
   # compile problems
   o1 <- as.list(compile(p1))
