@@ -1,5 +1,3 @@
-context("category_layer")
-
 test_that("SpatRaster", {
   # create data
   x <- c(
@@ -10,7 +8,7 @@ test_that("SpatRaster", {
   # convert to binary stack
   y <- category_layer(x)
   # tests
-  expect_is(y, "SpatRaster")
+  expect_inherits(y, "SpatRaster")
   expect_equal(terra::nlyr(y), 1)
   expect_true(is_comparable_raster(x, y))
   expect_equal(c(terra::values(y)), c(1, 2, 3, 0, NA, 3))
@@ -30,7 +28,7 @@ test_that("Raster", {
     "deprecated"
   )
   # tests
-  expect_equivalent(
+  expect_equal(
     terra::as.data.frame(y),
     terra::as.data.frame(terra::rast(z))
   )
