@@ -83,6 +83,7 @@ test_that("x = SpatRaster, features = SpatRaster", {
   )
   expect_equal(names(x$data$rij_matrix), x$zone_names())
   expect_equal(rownames(x$data$rij_matrix[[1]]), x$feature_names())
+  expect_true(x$has_negative_feature_data())
   # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
@@ -202,6 +203,7 @@ test_that("x = SpatRaster, features = ZonesSpatRaster", {
     ),
     ignore_attr = TRUE
   )
+  expect_true(x$has_negative_feature_data())
   # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
@@ -293,6 +295,7 @@ test_that("x = sf, features = SpatRaster", {
   )
   expect_equal(names(x$data$rij_matrix), "cost")
   expect_equal(rownames(x$data$rij_matrix[[1]]), names(sim_features))
+  expect_true(x$has_negative_feature_data())
   # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
@@ -414,6 +417,7 @@ test_that("x = sf, features = ZonesSpatRaster", {
     ),
     ignore_attr = TRUE
   )
+  expect_true(x$has_negative_feature_data())
   # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
@@ -510,6 +514,7 @@ test_that("x = sf, features = character", {
   expect_true(all(x$data$rij_matrix[[1]] == rij[[1]]))
   expect_equal(names(x$data$rij_matrix), "cost")
   expect_equal(rownames(x$data$rij_matrix[[1]]),  c("spp1", "spp2"))
+  expect_true(x$has_negative_feature_data())
   # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
@@ -518,18 +523,15 @@ test_that("x = sf, features = ZonesCharacter", {
   # import data
   sim_zones_pu_polygons <- get_sim_zones_pu_polygons()
   # update data
+  sim_zones_pu_polygons <- sim_zones_pu_polygons[1:5, ]
+  sim_zones_pu_polygons$cost_1[1] <- -1
   sim_zones_pu_polygons$cost_1[2] <- NA
   sim_zones_pu_polygons$cost_1[3] <- NA
   sim_zones_pu_polygons$cost_2[3] <- NA
-  sim_zones_pu_polygons$cost_1 <-
-    sim_zones_pu_polygons$cost_1 * runif(nrow(sim_zones_pu_polygons), -1, 1)
-  sim_zones_pu_polygons$spp1_1 <- runif(nrow(sim_zones_pu_polygons), -1, 1)
-  sim_zones_pu_polygons$spp2_1 <- c(
-    NA, rpois(nrow(sim_zones_pu_polygons) - 1, 5)
-  )
-  sim_zones_pu_polygons$spp1_2 <- runif(nrow(sim_zones_pu_polygons), -1, 1)
-  sim_zones_pu_polygons$spp2_2 <- runif(nrow(sim_zones_pu_polygons), -1, 1)
-  sim_zones_pu_polygons <- sim_zones_pu_polygons[1:5, ]
+  sim_zones_pu_polygons$spp1_1 <- c(1, 2, 3, 5, 1)
+  sim_zones_pu_polygons$spp2_1 <- c(NA, 2, 3, 9, 7)
+  sim_zones_pu_polygons$spp1_2 <- c(-0.5, 4, 5, 2, 4)
+  sim_zones_pu_polygons$spp2_2 <- c(0.5, 4, 5, 5, 1)
   # create problem
   w <- capture_warnings(
     x <- problem(
@@ -674,6 +676,7 @@ test_that("x = sf, features = ZonesCharacter", {
   expect_equal(names(x$data$rij_matrix), c("z1", "z2"))
   expect_true(all(x$data$rij_matrix[[1]] == rij[[1]]))
   expect_true(all(x$data$rij_matrix[[2]] == rij[[2]]))
+  expect_true(x$has_negative_feature_data())
   # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
@@ -756,6 +759,7 @@ test_that("x=data.frame, features=character", {
   )
   expect_equal(names(x$data$rij_matrix), "cost")
   expect_equal(rownames(x$data$rij_matrix[[1]]), c("spp1", "spp2"))
+  expect_true(x$has_negative_feature_data())
   # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
@@ -865,6 +869,7 @@ test_that("x = data.frame, features = ZonesCharacter", {
   expect_equal(names(x$data$rij_matrix), c("1", "2"))
   expect_equal(rownames(x$data$rij_matrix[[1]]), c("1", "2"))
   expect_equal(rownames(x$data$rij_matrix[[2]]), c("1", "2"))
+  expect_true(x$has_negative_feature_data())
   # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
@@ -940,6 +945,7 @@ test_that("x = data.frame, features = data.frame (single zone)", {
   )
   expect_equal(names(x$data$rij_matrix), "cost")
   expect_equal(rownames(x$data$rij_matrix[[1]]), letters[1:5])
+  expect_true(x$has_negative_feature_data())
   # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
@@ -1043,6 +1049,7 @@ test_that("x = data.frame, features = data.frame (multiple zones)", {
   )
   expect_equal(rownames(x$data$rij_matrix[[1]]), letters[1:5])
   expect_equal(rownames(x$data$rij_matrix[[2]]), letters[1:5])
+  expect_true(x$has_negative_feature_data())
   # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
@@ -1122,6 +1129,7 @@ test_that("x = numeric, features = data.frame", {
     ignore_attr = TRUE
   )
   expect_equal(rownames(x$data$rij_matrix[[1]]), c("spp1", "spp2"))
+  expect_true(x$has_negative_feature_data())
   # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
@@ -1223,6 +1231,7 @@ test_that("x = matrix, features = data.frame", {
   )
   expect_equal(rownames(x$data$rij_matrix[[1]]), c("spp1", "spp2"))
   expect_equal(rownames(x$data$rij_matrix[[2]]), c("spp1", "spp2"))
+  expect_true(x$has_negative_feature_data())
   # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
 })
